==> mfc-api-model-0.1.2-sources.jar: com/valor/mfc/vms/api/model/user/SubAccountDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

public class SubAccountDo extends AbstractPrintable {

    private Long accountId;
    private Integer accountType ; // 0 = device , 1 = account
    private boolean master;
    private Integer status;
    private Long subAccountId;
    private String subAccountName;
    private String did;
    private Long sortNo;

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }


    public boolean isMaster() {
        return master;
    }

    public void setMaster(boolean master) {
        this.master = master;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getSubAccountId() {
        return subAccountId;
    }

    public void setSubAccountId(Long subAccountId) {
        this.subAccountId = subAccountId;
    }

    public String getSubAccountName() {
        return subAccountName;
    }

    public void setSubAccountName(String subAccountName) {
        this.subAccountName = subAccountName;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getSortNo() {
        return sortNo;
    }

    public void setSortNo(Long sortNo) {
        this.sortNo = sortNo;
    }
}

==> mfc-api-model-0.1.3-sources.jar: com/valor/mfc/vms/api/model/user/SubAccountDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

public class SubAccountDo extends AbstractPrintable {

    private Long accountId;
    private Integer accountType ; // 0 = device , 1 = account
    private boolean master;
    private Integer status;
    private Long subAccountId;
    private String subAccountName;
    private String did;
    private Long sortNo;
    private Long iconId;

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }


    public boolean isMaster() {
        return master;
    }

    public void setMaster(boolean master) {
        this.master = master;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getSubAccountId() {
        return subAccountId;
    }

    public void setSubAccountId(Long subAccountId) {
        this.subAccountId = subAccountId;
    }

    public String getSubAccountName() {
        return subAccountName;
    }

    public void setSubAccountName(String subAccountName) {
        this.subAccountName = subAccountName;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getSortNo() {
        return sortNo;
    }

    public void setSortNo(Long sortNo) {
        this.sortNo = sortNo;
    }

    public Long getIconId() {
        return iconId;
    }

    public void setIconId(Long iconId) {
        this.iconId = iconId;
    }

    @Override
    public String toString() {
        return "SubAccountDo{" +
            "accountId=" + accountId +
            ", accountType=" + accountType +
            ", master=" + master +
            ", status=" + status +
            ", subAccountId=" + subAccountId +
            ", subAccountName='" + subAccountName + '\'' +
            ", did='" + did + '\'' +
            ", sortNo=" + sortNo +
            ", iconId=" + iconId +
            '}';
    }
}
